﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using MvcSecurityExample.Models;
using System.Web.Helpers;
using MvcSecurityExample.Provider;

namespace MvcSecurityExample.Controllers
{
    [Authorize]
    public class UserController : Controller
    {
        private MvcSecurityExampleModelContainer db = new MvcSecurityExampleModelContainer();

        //
        // GET: /User/

        public ActionResult Index()
        {
            var users = db.Users.Include("Group");
            return View(users.ToList());
        }

        //
        // GET: /User/Details/5

        public ActionResult Details(int id = 0)
        {
            User user = db.Users.Single(u => u.Id == id);
            if (user == null)
            {
                return HttpNotFound();
            }
            return View(user);
        }

        //
        // GET: /User/Create

        public ActionResult Create()
        {
            ViewBag.GroupId = new SelectList(db.Groups, "Id", "GroupLabel");
            return View();
        }

        //
        // POST: /User/Create

        [HttpPost]
        public ActionResult Create(User user)
        {
            if (string.IsNullOrWhiteSpace(user.Password))
            {
                ModelState.AddModelError("Password", "Пароль не должен быть пустым");
            }
                       
            if (ModelState.IsValid)
            {
                //Преобразование пароля в хэш при создании пользователя
                string passwordHash = CustomMembershipProvider.HashPassword(user.Password.Trim());
                user.Password = passwordHash;

                db.Users.AddObject(user);
                db.SaveChanges();
                return RedirectToAction("Index");
            }

            ViewBag.GroupId = new SelectList(db.Groups, "Id", "GroupLabel", user.GroupId);
            return View(user);
        }


        /// <summary>
        /// Изменение пароля текущего пользователя
        /// </summary>
        public ActionResult ChangePassword(int id = 0)
        {
            LocalPasswordModel modelPassword = new LocalPasswordModel()
            {
                ReturnController = "User",
                ReturnAction = "ChangePassword",
                isAdminReset = true,
                ReturnId = id 
            };

            return View("~/Views/Account/ChangePassword.cshtml", modelPassword);
        }

        [HttpPost]
        public ActionResult ChangePassword(LocalPasswordModel model)
        {
            MvcSecurityExampleModelContainer db = new MvcSecurityExampleModelContainer();

            //Проверка совпадения нового пароля и подтверждения
            if (model.NewPassword != model.ConfirmPassword)
            {
                ModelState.AddModelError("", "Новый пароль и подтверждение не совпадают");
            }

            if (ModelState.IsValid)
            {
                User user = db.Users.FirstOrDefault(x => x.Id == model.ReturnId);
                if (user != null)
                {
                    try
                    {
                        db.Users.Detach(user);
                    }
                    catch { }

                    user.Password = CustomMembershipProvider.HashPassword(model.NewPassword);
                    db.Users.Attach(user);
                    db.ObjectStateManager.ChangeObjectState(user, EntityState.Modified);
                    db.SaveChanges();
                }

                return RedirectToAction("Index");
            }

            return View(model);
        }

        //
        // GET: /User/Edit/5

        public ActionResult Edit(int id = 0)
        {
            User user = db.Users.Single(u => u.Id == id);
            if (user == null)
            {
                return HttpNotFound();
            }
            ViewBag.GroupId = new SelectList(db.Groups, "Id", "GroupLabel", user.GroupId);
            return View(user);
        }

        //
        // POST: /User/Edit/5

        [HttpPost]
        public ActionResult Edit(User user)
        {
            if (ModelState.IsValid)
            {
                db.Users.Attach(user);
                db.ObjectStateManager.ChangeObjectState(user, EntityState.Modified);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            ViewBag.GroupId = new SelectList(db.Groups, "Id", "GroupLabel", user.GroupId);
            return View(user);
        }

        //
        // GET: /User/Delete/5

        public ActionResult Delete(int id = 0)
        {
            User user = db.Users.Single(u => u.Id == id);
            if (user == null)
            {
                return HttpNotFound();
            }
            return View(user);
        }

        //
        // POST: /User/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {
            User user = db.Users.Single(u => u.Id == id);
            db.Users.DeleteObject(user);
            db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            db.Dispose();
            base.Dispose(disposing);
        }
    }
}