﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Http;
using System.Web.Mvc;
using System.Web.Optimization;
using System.Web.Routing;
using System.Web.SessionState;
using System.Web.Security;

namespace MvcSecurityExample
{
    // Примечание: Инструкции по включению классического режима IIS6 или IIS7 
    // см. по ссылке http://go.microsoft.com/?LinkId=9394801

    public class MvcApplication : System.Web.HttpApplication
    {
        protected void Application_Start()
        {
            AreaRegistration.RegisterAllAreas();

            WebApiConfig.Register(GlobalConfiguration.Configuration);
            FilterConfig.RegisterGlobalFilters(GlobalFilters.Filters);
            RouteConfig.RegisterRoutes(RouteTable.Routes);
            BundleConfig.RegisterBundles(BundleTable.Bundles);
            AuthConfig.RegisterAuth();
        }

        protected void Application_PreRequestHandlerExecute(object sender, EventArgs e)
        {
            /*
                Параметры Web.config:
              
                Время authenticationCookie - X1 в минутах
                <forms loginUrl="~/Account/Login" timeout="X1" />

                Время сессии - X2 в минутах
                <sessionState timeout="X2"></sessionState>
             
             */

            //Only access session state if it is available
            if (Context.Handler is IRequiresSessionState || Context.Handler is IReadOnlySessionState)
            {
                //If we are authenticated AND we dont have a session here.. redirect to login page.
                HttpCookie authenticationCookie = Request.Cookies[FormsAuthentication.FormsCookieName];
                if (authenticationCookie != null)
                {
                    FormsAuthenticationTicket authenticationTicket = FormsAuthentication.Decrypt(authenticationCookie.Value);
                    if (!authenticationTicket.Expired)
                    {
                        //MvcSecurityExample.Models.User.SessionUserVarName - можно использовать имя произвольной сессионной переменной
                        object obj = Session[MvcSecurityExample.Models.User.SessionUserVarName];
                        if (obj == null)
                        {
                            //This means for some reason the session expired before the authentication ticket. Force a login.
                            FormsAuthentication.SignOut();
                            Response.Redirect(FormsAuthentication.LoginUrl, true);
                            return;
                        }
                        else
                        {
                            //Пользователь есть в сессии, нужно проверить что он есть в БД
                            HttpSessionStateBase sessionBase = new HttpSessionStateWrapper(Session);
                            MvcSecurityExample.Models.User user = MvcSecurityExample.Models.User.GetCurrentUserFromSession(sessionBase);
                            if (user == null)
                            {
                                FormsAuthentication.SignOut();
                                Session.Abandon();
                                Response.Redirect(FormsAuthentication.LoginUrl, true);
                                return;
                            }
                        }
                    }
                }

                else
                {
                    //Если завершилась авторизация, необходимо закрыть сессию
                    object obj = Session[MvcSecurityExample.Models.User.SessionUserVarName];
                    if (obj != null)
                    {
                        Session.Abandon();
                        Response.Redirect(FormsAuthentication.LoginUrl, true);
                        return;
                    }
                }

            }
        }


    }
}