﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.ComponentModel.DataAnnotations;

namespace MvcSecurityExample.Models
{
    [MetadataType(typeof(GroupValidation))]
    public partial class Group
    {
    }

    public class GroupValidation
    {
        [Required]
        [Display(Name = "Наименование группы")]
        public object GroupLabel { get; set; }

        [Required]
        [Display(Name = "Служебное наименование группы")]
        public object GroupName { get; set; }
    }

    [MetadataType(typeof(UserValidation))]
    public partial class User
    {
        public const string AdminRole = "admins";
        public const string SessionUserVarName = "CurrentUserSessionVar";

        /// <summary>
        /// Является ли администратором
        /// </summary>
        public bool IsAdmin
        {
            get
            {
                MvcSecurityExampleModelContainer db = new MvcSecurityExampleModelContainer();
                bool Result = false;
                if(this.GroupId > 0) 
                {
                    Group grp = db.Groups.FirstOrDefault(x => x.Id == this.GroupId);
                    if (grp != null)
                    {
                        Result = (grp.GroupName == AdminRole);
                    }
                }

                return Result;
            }
        }

        /// <summary>
        /// Сохранение пользователя в сессию как текущего пользователя
        /// </summary>
        /// <param name="Session"></param>
        public void SaveToSession(HttpSessionStateBase Session)
        {
            Session.Add(SessionUserVarName, this.Id);
        }

        /// <summary>
        /// Получение текущего пользователя из сессии
        /// </summary>
        /// <param name="Session"></param>
        /// <returns></returns>
        public static User GetCurrentUserFromSession(HttpSessionStateBase Session)
        {
            MvcSecurityExampleModelContainer db = new MvcSecurityExampleModelContainer();
            object obj = Session[SessionUserVarName];
            if(obj == null)
            {
                return null;
            }
            else
            {
                int UserId = (int)obj;
                User user = db.Users.FirstOrDefault(x => x.Id == UserId);
                if (user == null)
                {
                    return null;
                }
                else
                {
                    db.Users.Detach(user);
                    return user;
                }
            }
        }
    }

    public class UserValidation
    {
        [Required]
        [Display(Name = "Имя пользователя")]
        public object Name { get; set; }

        [Required]
        [Display(Name = "Логин")]
        public object Login { get; set; }

        [Display(Name = "Пароль")]
        public object Password { get; set; }
    }

}